#include "postgresql-libpq-6.2.x.hh"
/*
*  Name:      test-1.uesql.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for UESQL
*  Date:      $Date: 1999/08/20 11:27:03 $
*  Revision:  $Revision: 1.7 $
*
*  Copyright (C) 1996-1999  Rafael Jesus Alcantara Perez <ralcan@vnet.es>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdlib>
#include <iostream>
#include <mpcl/config_processor.hh>
#include <mpcl/string.hh>
#include <mpcl/test.h>
#include <uesqlc/defs-uesqlc.cc>


//
//  U S E D   N A M E S P A C E S
//

using namespace mpcl;
using namespace uesql;


//
//  L O C A L   V A R I A B L E S
//

static TSqlstateHandler   _tSqlstateHandler;
  

//
//  L O C A L   F U N C T I O N S
//

static string _GetErrorMessage (void)
{

  return ( string (_tSqlstateHandler.getClass())    +
           ": "                                     +
           string (_tSqlstateHandler.getSubclass()) );

}  // _GetErrorMessage()


int TestCursors (void)
{

  string   yVar0;
  string   yVar1;
  bool     gEmpty = true;

  TEST_INIT ("test for cursors");

#line 73 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 74 "test-1.uesql.cc"

#line 75 "test-1.uesql.cc"
PGV_EXEC ("BEGIN;", htPostgresql62xManager._ptPgconn, htPostgresql62xManager.finish(); exit (1););
htPostgresql62xManager._ySqlStatement = Format ("DECLARE MYCURSOR CURSOR FOR SELECT NAME, HOURS FROM WORKERS;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, htPostgresql62xManager.finish(); exit (1););
#line 76 "test-1.uesql.cc"


}
  while ( true )
  {
#line 81 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 82 "test-1.uesql.cc"
{
int   J = 0;

htPostgresql62xManager._ySqlStatement = Format ("FETCH IN MYCURSOR;");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, htPostgresql62xManager.finish(); exit (1););
if ( PG62X_NOT_FOUND_CONDITION )
{
  // 
  //  Condition:  no data
  // 
  uesql::SQLCODE = 101; uesql::SQLSTATE = "02000";
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
  goto loop_end;
}
else
{
  yVar0 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
yVar1 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
}
}

}
    gEmpty = false;
  }

loop_end:
#line 89 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 90 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CLOSE MYCURSOR;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, htPostgresql62xManager.finish(); exit (1););
PGV_EXEC ("END;", htPostgresql62xManager._ptPgconn, htPostgresql62xManager.finish(); exit (1););


}
  if ( gEmpty )
  {
    TEST_PASS;
  }
  else
  {
    TEST_FAIL;
  }
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;
  
}  // TestCursors()


int TestSchemas (const string& rkySOURCE_HOSTNAME, const string& rkyUSER)
{

  TEST_INIT ("test for schemas");

  mpcl::xstring   yNewSchemaServer = Format ("%s/TEST_1_SCHEMA", rkySOURCE_HOSTNAME.c_str());
  
#line 114 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 115 "test-1.uesql.cc"

#line 130 "test-1.uesql.cc"
{
mpcl::xstring   hyConnectionName;
mpcl::xstring   hyLastConnectionName = htPostgresql62xManager.currentConnectionName();

hyConnectionName                      = Format ("TEST_1_SCHEMA");
htPostgresql62xManager._ySqlStatement = Format ("CREATE DATABASE %s;", hyConnectionName.c_str());
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager._ptPgconn = PQsetdb (htPostgresql62xManager._yHost.c_str(), NULL, NULL, NULL, hyConnectionName.c_str());
if ( PQstatus (htPostgresql62xManager._ptPgconn) != CONNECTION_BAD )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  SQL-client unable to establish SQL-connection
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08001";
  goto error;
}
if ( htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08002";
  goto error;
}
htPostgresql62xManager.connect (hyConnectionName, htPostgresql62xManager._ptPgconn);
htPostgresql62xManager.setCurrentConnection (hyConnectionName);
htPostgresql62xManager._ySqlStatement = Format ("CREATE TABLE TABLE_1 (CODE CHAR (3) NOT NULL, WORKER_COUNT INT4);");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager._ySqlStatement = Format ("CREATE TABLE TABLE_2 (WORK_CODE CHAR (3) NOT NULL, NAME CHAR (40) NOT NULL, HOURS DECIMAL (5));");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager.disconnectCurrent();
htPostgresql62xManager._ptPgconn = htPostgresql62xManager.setCurrentConnection (hyLastConnectionName);
}
#line 131 "test-1.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
const char*     hpakcVariables[] = { NULL , yNewSchemaServer.c_str(), rkyUSER.c_str() };

//
//  '%s' has been omitted.
//
hySqlServerDescriptor = PG62X_INSTANTIATE ("%s",  0, hpakcVariables);
hyConnectionName      = PG62X_INSTANTIATE ("_'myconnection'", 1, hpakcVariables);
hySqlServerDescriptor.suppress ('\'');
hyConnectionName.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == string::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
htPostgresql62xManager._yHost         = hySqlServerName;
htPostgresql62xManager._yDatabaseName = hyDatabaseName;
if ( htPostgresql62xManager._yDatabaseName.empty() )
{
  htPostgresql62xManager._yDatabaseName = getenv ("USER");
}
htPostgresql62xManager._ptPgconn = PQsetdb (htPostgresql62xManager._yHost.c_str(), NULL, NULL, NULL, htPostgresql62xManager._yDatabaseName.c_str());
if ( PQstatus (htPostgresql62xManager._ptPgconn) != CONNECTION_BAD )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  SQL-client unable to establish SQL-connection
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08001";
  goto error;
}
if ( htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08002";
  goto error;
}
htPostgresql62xManager.connect (hyConnectionName, htPostgresql62xManager._ptPgconn);
htPostgresql62xManager.setCurrentConnection (hyConnectionName);
}
#line 132 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("DROP TABLE TABLE_1;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 133 "test-1.uesql.cc"
{
if ( htPostgresql62xManager.existsDefaultConnection() )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
  htPostgresql62xManager.disconnectCurrent();
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08003";
  goto error;
}
}
#line 134 "test-1.uesql.cc"
{
string        hyConnectionName;
const char*   hpakcVariables[] = { NULL  };

hyConnectionName = PG62X_INSTANTIATE ("DEFAULT", 0, hpakcVariables);
htPostgresql62xManager._ptPgconn = htPostgresql62xManager.setCurrentConnection (hyConnectionName);
if ( !htPostgresql62xManager._ptPgconn )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08003";
  goto error;
}
}
#line 135 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("DROP DATABASE TEST_1_SCHEMA;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);

}
  TEST_PASS;
  goto end;

error:
  cerr << "SQLSTATE="    << SQLSTATE << endl;
  cerr << "SQLCODE="     << SQLCODE  << endl;
  cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
  TEST_FAIL_WITH_CODE (SQLCODE);  

end:  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;
  
}  // TestSchemas()


/**
*  Main.
*
*  Parameters:
*
*    {--hostname, -o}=HOSTNAME
*    {--username, -u}=USERNAME
*    {--password, -p}=PASSWORD
*/
int main (int argc, const char* argv[])
{

  TConfigProcessor   tConfig;
  size_t             zRecordCount = 0;

  TEST_INIT ("test-base-1");
  TEST_START_WATCH;

  string   yVar0;
  string   yVar1;
  string   yVar2;
  string   yAttribName;
  string   yCursorName;
  string   yUserName;
  string   yHostName;
  string   yCodeValue = "'002'";

  try
  {
    //
    //  Define string constants names for options.
    // 
    tConfig.addOption ("hostname", "o", "localhost");
    tConfig.addOption ("username", "u", getenv ("USER"));
    tConfig.addOption ("password", "p", "");
    tConfig.setCommandLineParameters (argc, argv);
    tConfig.processOptions();
    
    yHostName = Format ("'%s'", tConfig ["hostname"].value().c_str());
    if ( tConfig ["password"].value().empty() )
    {
      yUserName = Format ("'%s'", tConfig ["username"].value().c_str());
    }
    else
    {
      yUserName = Format ( "'%s/%s'"                            ,
                           tConfig ["username"].value().c_str() ,
                           tConfig ["password"].value().c_str() );
    }
  }
  catch (const TBaseException& rktSOURCE_EXCEPTION)
  {
    cerr << rktSOURCE_EXCEPTION;
    TEST_FAIL_WITH_CODE (3);
  }

  TEST_WRITE_INFO ("HOSTNAME = %s", yHostName.c_str());
  TEST_WRITE_INFO ("USER     = %s", yUserName.c_str());
  if ( !yHostName.empty() && !yUserName.empty() )
  {
#line 214 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 218 "test-1.uesql.cc"

#line 219 "test-1.uesql.cc"

#line 224 "test-1.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
const char*     hpakcVariables[] = { NULL , yHostName.c_str(), yUserName.c_str() };

//
//  '%s' has been omitted.
//
hySqlServerDescriptor = PG62X_INSTANTIATE ("%s",  0, hpakcVariables);
hyConnectionName      = "DEFAULT";
hySqlServerDescriptor.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == string::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
htPostgresql62xManager._yHost         = hySqlServerName;
htPostgresql62xManager._yDatabaseName = hyDatabaseName;
if ( htPostgresql62xManager.isConnected (hyConnectionName) )
{
  htPostgresql62xManager.disconnect (hyConnectionName);
}
if ( htPostgresql62xManager._yDatabaseName.empty() )
{
  htPostgresql62xManager._yDatabaseName = getenv ("USER");
}
htPostgresql62xManager._ptPgconn = PQsetdb (htPostgresql62xManager._yHost.c_str(), NULL, NULL, NULL, htPostgresql62xManager._yDatabaseName.c_str());
if ( PQstatus (htPostgresql62xManager._ptPgconn) != CONNECTION_BAD )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  SQL-client unable to establish SQL-connection
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08001";
  goto error;
}
if ( htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08002";
  goto error;
}
htPostgresql62xManager.connect (hyConnectionName, htPostgresql62xManager._ptPgconn);
htPostgresql62xManager.setCurrentConnection (hyConnectionName);
}
#line 233 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CREATE TABLE JOBS (CODE CHAR (3) NOT NULL, WORKER_COUNT INT4);");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 240 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CREATE TABLE WORKERS (WORK_CODE CHAR (3) NOT NULL, NAME CHAR (40) NOT NULL, HOURS DECIMAL (5));");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 245 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("ALTER TABLE WORKERS ADD COLUMN STATE CHAR (40);");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 246 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("ALTER TABLE WORKERS ADD COLUMN PHONE_NUMBER INT4;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 251 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("DELETE FROM JOBS WHERE ( CODE = %s );", yCodeValue.c_str());
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 252 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("DELETE FROM JOBS WHERE ( CODE = '001' );");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 253 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("DELETE FROM WORKERS;");
PGV_EXEC ("DELETE FROM WORKERS;", htPostgresql62xManager._ptPgconn, goto error;);
#line 258 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO JOBS VALUES ('001', 100);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 259 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO JOBS VALUES ('002', 250);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 260 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS VALUES ('001', 'myname', 40, 'Andalucia', 5550000);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 261 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS VALUES ('001', 'yourname', 35, 'Extremadura', 5550001);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 262 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS VALUES ('001', 'hisname', 25, 'Catalunya', 5550002);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 263 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS VALUES ('002', 'john', 35, 'New England', 5550003);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 264 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS VALUES ('002', 'james', 35, 'Washington', 5550004);");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 265 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS WHERE ( NAME = 'myname' );");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 266 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS;");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 273 "test-1.uesql.cc"

#line 274 "test-1.uesql.cc"
{
int   J = 0;

PGV_EXEC ("BEGIN;", htPostgresql62xManager._ptPgconn, goto cardinality_check;);
htPostgresql62xManager._ySqlStatement = Format ("DECLARE AUX_CURSOR CURSOR FOR SELECT HOURS FROM WORKERS, JOBS WHERE ( WORK_CODE = CODE );");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto cardinality_check;);
PG_EXEC ("FETCH ALL IN AUX_CURSOR;", htPostgresql62xManager._ptPgconn, goto cardinality_check;);
if ( PG62X_NOT_FOUND_CONDITION )
{
  // 
  //  Condition:  no data
  // 
  uesql::SQLCODE = 101; uesql::SQLSTATE = "02000";
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGIV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn);
  PGIV_EXEC ("END;", htPostgresql62xManager._ptPgconn);
  goto not_found;
}
else if ( PQntuples (htPostgresql62xManager._ptPgresult) != 1 )
{
  // 
  //  Condition:  cardinality violation
  // 
  uesql::SQLCODE = -1; uesql::SQLSTATE = "21000"; 
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGIV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn);
  PGIV_EXEC ("END;", htPostgresql62xManager._ptPgconn);
  goto cardinality_check;
}
else
{
  uesql::SQLCODE = 0; uesql::SQLSTATE = "00000";
  yVar1 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn, goto cardinality_check;);
  PGV_EXEC ("END;", htPostgresql62xManager._ptPgconn, goto cardinality_check;);
}
}

}
    TEST_FAIL;

cardinality_check:
    TEST_STRINGS (SQLSTATE.c_str(), "21000");
    yAttribName = "WORK_CODE";
    yCursorName = "MYCURSOR";
#line 283 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 287 "test-1.uesql.cc"

#line 292 "test-1.uesql.cc"
{
int   J = 0;

PGV_EXEC ("BEGIN;", htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager._ySqlStatement = Format ("DECLARE AUX_CURSOR CURSOR FOR SELECT COUNT (*) FROM WORKERS WHERE ( NAME = 'myname' );");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
PG_EXEC ("FETCH ALL IN AUX_CURSOR;", htPostgresql62xManager._ptPgconn, goto error;);
if ( PG62X_NOT_FOUND_CONDITION )
{
  // 
  //  Condition:  no data
  // 
  uesql::SQLCODE = 101; uesql::SQLSTATE = "02000";
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGIV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn);
  PGIV_EXEC ("END;", htPostgresql62xManager._ptPgconn);
  goto not_found;
}
else if ( PQntuples (htPostgresql62xManager._ptPgresult) != 1 )
{
  // 
  //  Condition:  cardinality violation
  // 
  uesql::SQLCODE = -1; uesql::SQLSTATE = "21000"; 
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGIV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn);
  PGIV_EXEC ("END;", htPostgresql62xManager._ptPgconn);
  goto error;
}
else
{
  uesql::SQLCODE = 0; uesql::SQLSTATE = "00000";
  yVar2 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
  if ( htPostgresql62xManager._ptPgresult ) PQclear (htPostgresql62xManager._ptPgresult);
  PGV_EXEC ("CLOSE AUX_CURSOR;", htPostgresql62xManager._ptPgconn, goto error;);
  PGV_EXEC ("END;", htPostgresql62xManager._ptPgconn, goto error;);
}
}
#line 299 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("UPDATE WORKERS SET PHONE_NUMBER = WORKERS.PHONE_NUMBER WHERE ( ( WORKERS.NAME = 'myname' ) AND ( WORKERS.NAME = NAME ) );");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 304 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("REVOKE ALL PRIVILEGES ON JOBS FROM PUBLIC;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 305 "test-1.uesql.cc"
//
//  'RESTRICT' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("REVOKE ALL PRIVILEGES ON WORKERS FROM PUBLIC;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 310 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("GRANT SELECT ON JOBS TO PUBLIC;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 315 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CREATE VIEW VIEW1 AS SELECT * FROM JOBS;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 320 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("DROP VIEW VIEW1;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 325 "test-1.uesql.cc"
PGV_EXEC ("BEGIN;", htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager._ySqlStatement = Format ("DECLARE MYCURSOR CURSOR FOR SELECT CODE FROM JOBS WHERE ( CODE = '001' );");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 326 "test-1.uesql.cc"

#line 327 "test-1.uesql.cc"
{
int   J = 0;

htPostgresql62xManager._ySqlStatement = Format ("FETCH IN %s;", yCursorName.c_str());
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
if ( PG62X_NOT_FOUND_CONDITION )
{
  //
  //  Condition:  no data
  // 
  uesql::SQLCODE = 101; uesql::SQLSTATE = "02000";
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
  goto not_found;
}
else
{
  yVar0 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
}
}
#line 328 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CLOSE MYCURSOR;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
PGV_EXEC ("END;", htPostgresql62xManager._ptPgconn, goto error;);

#line 333 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("DROP TABLE JOBS;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);

}

    TEST_STRINGS (SQLSTATE.c_str(), "00000");
    TEST_STRINGS (yVar2.c_str(),    "4");
    TEST_STRINGS (yVar0.c_str(),    "001");

#line 341 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 345 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("GRANT SELECT ON WORKERS TO PUBLIC;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 346 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("GRANT DELETE ON WORKERS TO PUBLIC;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 351 "test-1.uesql.cc"

#line 352 "test-1.uesql.cc"
PGV_EXEC ("BEGIN;", htPostgresql62xManager._ptPgconn, goto error;);
htPostgresql62xManager._ySqlStatement = Format ("DECLARE MYCURSOR CURSOR FOR SELECT %s, NAME, HOURS FROM WORKERS;", yAttribName.c_str());
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
#line 353 "test-1.uesql.cc"


}
    
    if ( _ptTargetFile )
    {
      fprintf (_ptTargetFile, "%s\n", "WORK_CODE NAME                                     HOURS");
      fprintf (_ptTargetFile, "%s\n", "========= ======================================== =====");
    }
    while ( true )
    {
#line 364 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 365 "test-1.uesql.cc"
{
int   J = 0;

htPostgresql62xManager._ySqlStatement = Format ("FETCH IN MYCURSOR;");
PG_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
if ( PG62X_NOT_FOUND_CONDITION )
{
  // 
  //  Condition:  no data
  // 
  uesql::SQLCODE = 101; uesql::SQLSTATE = "02000";
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
  goto loop_end;
}
else
{
  yVar0 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
yVar1 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
yVar2 = PQgetvalue (htPostgresql62xManager._ptPgresult, 0, J++);
  if ( htPostgresql62xManager._ptPgresult ) { PQclear (htPostgresql62xManager._ptPgresult); }
}
}

}
      if ( _ptTargetFile )
      {
        fprintf (_ptTargetFile, "%9s %40s %5s\n", yVar0.c_str(), yVar1.c_str(), yVar2.c_str());
      }
      ++zRecordCount;
    }


  loop_end:
#line 377 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 381 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("CLOSE MYCURSOR;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);
PGV_EXEC ("END;", htPostgresql62xManager._ptPgconn, goto error;);

#line 385 "test-1.uesql.cc"
htPostgresql62xManager._ySqlStatement = Format ("DELETE FROM WORKERS;");
PGV_EXEC ("DELETE FROM WORKERS;", htPostgresql62xManager._ptPgconn, goto error;);

}
    TestCursors();
    TestSchemas (yHostName, yUserName);
    
#line 391 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 395 "test-1.uesql.cc"
{
if ( htPostgresql62xManager.existsDefaultConnection() )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
  htPostgresql62xManager.disconnectCurrent();
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection does not exist
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08003";
  goto error;
}
}

}

#line 399 "test-1.uesql.cc"
{
//
//  SQL instructions.
//
#line 403 "test-1.uesql.cc"
{
mpcl::xstring   hySqlServerDescriptor;
mpcl::xstring   hySqlServerName;
mpcl::xstring   hyDatabaseName;
mpcl::xstring   hyConnectionName;
const char*     hpakcVariables[] = { NULL , yHostName.c_str(), yUserName.c_str() };

//
//  '%s' has been omitted.
//
hySqlServerDescriptor = PG62X_INSTANTIATE ("%s",  0, hpakcVariables);
hyConnectionName      = PG62X_INSTANTIATE ("_'myconnection'", 1, hpakcVariables);
hySqlServerDescriptor.suppress ('\'');
hyConnectionName.suppress ('\'');
if ( hySqlServerDescriptor.find ('/') == string::npos )
{
  hySqlServerName = hySqlServerDescriptor;
}
else
{
  hySqlServerName = hySqlServerDescriptor.substr (0, hySqlServerDescriptor.find ('/'));
  hyDatabaseName  = hySqlServerDescriptor.substr (hySqlServerDescriptor.find ('/') + 1);
}
htPostgresql62xManager._yHost         = hySqlServerName;
htPostgresql62xManager._yDatabaseName = hyDatabaseName;
if ( htPostgresql62xManager._yDatabaseName.empty() )
{
  htPostgresql62xManager._yDatabaseName = getenv ("USER");
}
htPostgresql62xManager._ptPgconn = PQsetdb (htPostgresql62xManager._yHost.c_str(), NULL, NULL, NULL, htPostgresql62xManager._yDatabaseName.c_str());
if ( PQstatus (htPostgresql62xManager._ptPgconn) != CONNECTION_BAD )
{
  uesql::SQLCODE  = 0;
  uesql::SQLSTATE = "00000";
}
else
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  SQL-client unable to establish SQL-connection
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08001";
  goto error;
}
if ( htPostgresql62xManager.isConnected (hyConnectionName) )
{
  //
  //  Condition:           connection exception
  //  Class subcondition:  connection name in use
  //
  uesql::SQLCODE  = -1;
  uesql::SQLSTATE = "08002";
  goto error;
}
htPostgresql62xManager.connect (hyConnectionName, htPostgresql62xManager._ptPgconn);
htPostgresql62xManager.setCurrentConnection (hyConnectionName);
}
#line 408 "test-1.uesql.cc"
//
//  'CASCADE' has been omitted.
//
htPostgresql62xManager._ySqlStatement = Format ("DROP TABLE WORKERS;");
PGV_EXEC (htPostgresql62xManager._ySqlStatement.c_str(), htPostgresql62xManager._ptPgconn, goto error;);

}
    goto end;

    
  error:
    cerr << "SQLSTATE="    << SQLSTATE << endl;
    cerr << "SQLCODE="     << SQLCODE  << endl;
    cerr << "DESCRIPTION=" << _GetErrorMessage() << endl;
    TEST_FAIL_WITH_CODE (SQLCODE);  
    goto end;

  not_found:
    cerr << "Search failed\n";
    TEST_FAIL_WITH_CODE (2);
    goto end;
  }

end:
  TEST_STOP_WATCH;
  TEST_DISPLAY_WATCH;
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
